@@ -13,7 +13,8 @@ def make_values(values):
             for k, v in item.items():
                 walk(v, f"{path + (path and '.')}{k}")
         else:
-            value = json.dumps(item)  # .replace('"', "")
+            # value = json.dumps(item)  # .replace('"', "")
+            value = str(item).replace("True", "true").replace("False", "false")
             flat_values.append(f"{path}={value}")
 
     for value in values:
